@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::MakeMaker::Fallback;
-# git description: v0.015-1-g1a9fefb
-$Dist::Zilla::Plugin::MakeMaker::Fallback::VERSION = '0.016';
+package Dist::Zilla::Plugin::MakeMaker::Fallback; # git description: v0.016-17-gf4cff03
 # ABSTRACT: Generate a Makefile.PL containing a warning for legacy users
 # KEYWORDS: plugin installer MakeMaker Makefile.PL toolchain legacy ancient backcompat
-# vim: set ts=8 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+
+our $VERSION = '0.017';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::MakeMaker::Awesome' => { -version => '0.15' };
@@ -48,6 +48,18 @@ sub after_build
     $self->log_fatal('No Build.PL found to fall back from!') if not $build_pl;
 }
 
+around _build_WriteMakefile_args => sub
+{
+    my $orig = shift;
+    my $self = shift;
+    my $WriteMakefile_args = $self->$orig(@_);
+
+    return +{
+        PL_FILES => {}, # to avoid Build.PL from slipping in on EUMM < 6.25
+        %$WriteMakefile_args,
+    };
+};
+
 around _build_MakeFile_PL_template => sub
 {
     my $orig = shift;
@@ -84,10 +96,19 @@ if (not @missing)
 }
 else
 {
-    $ENV{PERL_MM_FALLBACK_SILENCE_WARNING} or warn <<'EOW';
+    if (not $ENV{PERL_MM_FALLBACK_SILENCE_WARNING})
+    {
+        warn <<'EOW';
 CODE
         . join('', <DATA>)
-        . "\nEOW\n\n    sleep 10 if -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT));\n}\n}\n\n";
+        . <<'CODE';
+EOW
+        sleep 10 if -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT));
+    }
+}
+} # end BEGIN
+
+CODE
 
     my $string = $self->$orig(@_);
 
@@ -234,7 +255,7 @@ Dist::Zilla::Plugin::MakeMaker::Fallback - Generate a Makefile.PL containing a w
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 SYNOPSIS
 
